package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.cryptopro.ECGOST3410NamedCurves;
import cn.com.infosec.asn1.nist.NISTNamedCurves;
import cn.com.infosec.asn1.sec.SECNamedCurves;
import cn.com.infosec.asn1.teletrust.TeleTrusTNamedCurves;
import cn.com.infosec.asn1.x9.X962NamedCurves;
import cn.com.infosec.asn1.x9.X9ECParameters;
import cn.com.infosec.crypto.params.AsymmetricKeyParameter;
import cn.com.infosec.crypto.params.ECDomainParameters;
import cn.com.infosec.crypto.params.ECPrivateKeyParameters;
import cn.com.infosec.crypto.params.ECPublicKeyParameters;
import cn.com.infosec.jce.interfaces.ECPrivateKey;
import cn.com.infosec.jce.interfaces.ECPublicKey;
import cn.com.infosec.jce.spec.ECParameterSpec;
import cn.com.infosec.math.ec.ECCurve;
import cn.com.infosec.math.ec.ECPoint;
import java.math.BigInteger;
import java.security.InvalidKeyException;
import java.security.PrivateKey;
import java.security.PublicKey;

public class ECUtil {
   static int[] convertMidTerms(int[] k) {
      int[] var1 = new int[3];
      if (k.length == 1) {
         var1[0] = k[0];
      } else {
         if (k.length != 3) {
            throw new IllegalArgumentException("Only Trinomials and pentanomials supported");
         }

         if (k[0] < k[1] && k[0] < k[2]) {
            var1[0] = k[0];
            if (k[1] < k[2]) {
               var1[1] = k[1];
               var1[2] = k[2];
            } else {
               var1[1] = k[2];
               var1[2] = k[1];
            }
         } else if (k[1] < k[2]) {
            var1[0] = k[1];
            if (k[0] < k[2]) {
               var1[1] = k[0];
               var1[2] = k[2];
            } else {
               var1[1] = k[2];
               var1[2] = k[0];
            }
         } else {
            var1[0] = k[2];
            if (k[0] < k[1]) {
               var1[1] = k[0];
               var1[2] = k[1];
            } else {
               var1[1] = k[1];
               var1[2] = k[0];
            }
         }
      }

      return var1;
   }

   static AsymmetricKeyParameter generatePublicKeyParameter(PublicKey key) {
      if (key instanceof ECPublicKey) {
         ECParameterSpec var1;
         ECPublicKey key1;
         ECParameterSpec var10005;
         ECParameterSpec var10006;
         if ((var1 = (key1 = (ECPublicKey)key).getParameters()) == null) {
            var1 = ProviderUtil.getEcImplicitlyCa();
            ECPoint var15 = ((JCEECPublicKey)key1).engineGetQ();
            var10005 = var1;
            var10006 = var1;
            ECParameterSpec var10007 = var1;
            ECCurve key3 = var1.getCurve();
            ECPoint var11 = var1.getG();
            BigInteger var12 = var10007.getN();
            BigInteger var13 = var10006.getH();
            byte[] var14 = var10005.getSeed();
            return new ECPublicKeyParameters(var15, new ECDomainParameters(key3, var11, var12, var13, var14));
         } else {
            ECPoint key2 = key1.getQ();
            ECDomainParameters var2;
            ECDomainParameters var10002 = var2 = new ECDomainParameters;
            ECParameterSpec var10003 = var1;
            ECParameterSpec var10004 = var1;
            var10005 = var1;
            var10006 = var1;
            ECCurve var10 = var1.getCurve();
            ECPoint var3 = var10006.getG();
            BigInteger var4 = var10005.getN();
            BigInteger var5 = var10004.getH();
            byte[] var6 = var10003.getSeed();
            var10002.<init>(var10, var3, var4, var5, var6);
            return new ECPublicKeyParameters(key2, var2);
         }
      } else {
         throw new InvalidKeyException("can't identify EC public key.");
      }
   }

   static AsymmetricKeyParameter generatePrivateKeyParameter(PrivateKey key) {
      if (key instanceof ECPrivateKey) {
         ECParameterSpec var1;
         ECPrivateKey key1;
         if ((var1 = (key1 = (ECPrivateKey)key).getParameters()) == null) {
            var1 = ProviderUtil.getEcImplicitlyCa();
         }

         BigInteger key2 = key1.getD();
         ECDomainParameters var2;
         ECDomainParameters var10002 = var2 = new ECDomainParameters;
         ECParameterSpec var10003 = var1;
         ECParameterSpec var10004 = var1;
         ECParameterSpec var10005 = var1;
         ECParameterSpec var10006 = var1;
         ECCurve var9 = var1.getCurve();
         ECPoint var3 = var10006.getG();
         BigInteger var4 = var10005.getN();
         BigInteger var5 = var10004.getH();
         byte[] var6 = var10003.getSeed();
         var10002.<init>(var9, var3, var4, var5, var6);
         return new ECPrivateKeyParameters(key2, var2);
      } else {
         throw new InvalidKeyException("can't identify EC private key.");
      }
   }

   public static DERObjectIdentifier getNamedCurveOid(String name) {
      DERObjectIdentifier var1;
      if ((var1 = X962NamedCurves.getOID(name)) == null) {
         if ((var1 = SECNamedCurves.getOID(name)) == null) {
            var1 = NISTNamedCurves.getOID(name);
         }

         if (var1 == null) {
            var1 = TeleTrusTNamedCurves.getOID(name);
         }

         if (var1 == null) {
            var1 = ECGOST3410NamedCurves.getOID(name);
         }
      }

      return var1;
   }

   public static X9ECParameters getNamedCurveByOid(DERObjectIdentifier oid) {
      X9ECParameters var1;
      if ((var1 = X962NamedCurves.getByOID(oid)) == null) {
         if ((var1 = SECNamedCurves.getByOID(oid)) == null) {
            var1 = NISTNamedCurves.getByOID(oid);
         }

         if (var1 == null) {
            var1 = TeleTrusTNamedCurves.getByOID(oid);
         }
      }

      return var1;
   }

   public static String getCurveName(DERObjectIdentifier oid) {
      String var1;
      if ((var1 = X962NamedCurves.getName(oid)) == null) {
         if ((var1 = SECNamedCurves.getName(oid)) == null) {
            var1 = NISTNamedCurves.getName(oid);
         }

         if (var1 == null) {
            var1 = TeleTrusTNamedCurves.getName(oid);
         }
      }

      return var1;
   }
}
